==> ejc-jlincome-api-3.0.0-20240510.080840-73-sources.jar: com/ejianc/business/jlincome/income/vo/ReviewDepartVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-合同评审-评审部门
 * 
 * @author generator
 * 
 */
public class ReviewDepartVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long reviewId; // 主表id
    private String departReviewType; // 评审类型
    private String departReviewDepart; // 评审部门
    private Long departReviewPersonId; // 评审部门负责人id
    private String departReviewPersonName; // 评审部门负责人name
    private String departReviewOpinion; // 评审意见
    private String departMemo; // 备注
    

    public Long getReviewId() {
        return reviewId;
    }

    public void setReviewId(Long reviewId) {
        this.reviewId = reviewId;
    }
    public String getDepartReviewType() {
        return departReviewType;
    }

    public void setDepartReviewType(String departReviewType) {
        this.departReviewType = departReviewType;
    }
    public String getDepartReviewDepart() {
        return departReviewDepart;
    }

    public void setDepartReviewDepart(String departReviewDepart) {
        this.departReviewDepart = departReviewDepart;
    }
    public Long getDepartReviewPersonId() {
        return departReviewPersonId;
    }

    public void setDepartReviewPersonId(Long departReviewPersonId) {
        this.departReviewPersonId = departReviewPersonId;
    }
    public String getDepartReviewPersonName() {
        return departReviewPersonName;
    }

    public void setDepartReviewPersonName(String departReviewPersonName) {
        this.departReviewPersonName = departReviewPersonName;
    }
    public String getDepartReviewOpinion() {
        return departReviewOpinion;
    }

    public void setDepartReviewOpinion(String departReviewOpinion) {
        this.departReviewOpinion = departReviewOpinion;
    }
    public String getDepartMemo() {
        return departMemo;
    }

    public void setDepartMemo(String departMemo) {
        this.departMemo = departMemo;
    }
    
}

==> ejc-jlincome-api-3.0.0-20240927.045143-255-sources.jar: com/ejianc/business/jlincome/income/vo/ReviewDepartVO.java <==
package com.ejianc.business.jlincome.income.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-合同评审-评审部门
 * 
 * @author generator
 * 
 */
public class ReviewDepartVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long reviewId; // 主表id
    private Long departReviewTypeId; // 评审类型
    private String departReviewTypeName; // 评审类型
    private String departReviewDepart; // 评审部门
    private Long departReviewPersonId; // 评审部门负责人id
    private String departReviewPersonName; // 评审部门负责人name
    private String departReviewOpinion; // 评审意见
    private String departMemo; // 备注

    public String getDepartReviewTypeName() {
        return departReviewTypeName;
    }

    public void setDepartReviewTypeName(String departReviewTypeName) {
        this.departReviewTypeName = departReviewTypeName;
    }

    public Long getReviewId() {
        return reviewId;
    }

    public void setReviewId(Long reviewId) {
        this.reviewId = reviewId;
    }
    public Long getDepartReviewTypeId() {
        return departReviewTypeId;
    }

    public void setDepartReviewTypeId(Long departReviewTypeId) {
        this.departReviewTypeId = departReviewTypeId;
    }
    public String getDepartReviewDepart() {
        return departReviewDepart;
    }

    public void setDepartReviewDepart(String departReviewDepart) {
        this.departReviewDepart = departReviewDepart;
    }
    public Long getDepartReviewPersonId() {
        return departReviewPersonId;
    }

    public void setDepartReviewPersonId(Long departReviewPersonId) {
        this.departReviewPersonId = departReviewPersonId;
    }
    public String getDepartReviewPersonName() {
        return departReviewPersonName;
    }

    public void setDepartReviewPersonName(String departReviewPersonName) {
        this.departReviewPersonName = departReviewPersonName;
    }
    public String getDepartReviewOpinion() {
        return departReviewOpinion;
    }

    public void setDepartReviewOpinion(String departReviewOpinion) {
        this.departReviewOpinion = departReviewOpinion;
    }
    public String getDepartMemo() {
        return departMemo;
    }

    public void setDepartMemo(String departMemo) {
        this.departMemo = departMemo;
    }
    
}
